# PySBOM
# Copyright (C) 2026-present Anton Lydell
# SPDX-License-Identifier: GPL-3.0-or-later

"""Execute the PySBOM CLI as `python -m pysbom`."""

# Local
from pysbom.cli.main import main

if __name__ == '__main__':
    main()
